************************
Basic reduction routines
************************

.. toctree::
    :maxdepth: 1

    reduction/imarith.rst
    reduction/ccdprocessing.rst
    reduction/photometry.rst
    reduction/registering.rst
    reduction/polarimetry.rst
    reduction/astrometry.rst
    reduction/pipelines.rst
